package net.rzdata.demo.dict;

import net.rzdata.demo.dict.domain.Dict;
import net.rzdata.demo.dict.mapper.DictRepository;
import net.rzdata.exception.RepeatDataException;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;
import java.util.Optional;

@Service
public class DictService {

    private final DictRepository dictRepository;

    public DictService(DictRepository dictRepository) {
        this.dictRepository = dictRepository;
    }

    protected void addDict(Dict dict) {
        Optional<Dict> exist = this.getDictByTypeAndValue(dict.getType(), dict.getValue());
        if (exist.isPresent()) {
            throw new RepeatDataException(String.format("字典类型:%s, 值:%s 已存在", dict.getType(), dict.getValue()));
        }
        dictRepository.get().insert(dict);
    }

    protected List<Dict> getDictByType(String type) {
        return dictRepository.findByTypeOrderBySortAsc(type);
    }

    private Optional<Dict> getDictByTypeAndValue(String type, String value) {
        List<Dict> dictList = this.getDictByType(type);
        return dictList.parallelStream()
            .filter(d -> Objects.equals(d.getValue(), value))
            .findAny();
    }
}
